import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { DataSource, Repository } from 'typeorm';
import { BlogPost } from './blogpost.entity';
import { CreateBlogPostDto } from './dto/create-blog-post.dto';

@Injectable()
export class BlogPostsService {
  constructor(
    @InjectRepository(BlogPost)
    private blogPostsRepository: Repository<BlogPost>
  ) {}

  findAll(): Promise<BlogPost[]> {
    return this.blogPostsRepository.find();
  }

  findOne(id: number): Promise<BlogPost | null> {
    return this.blogPostsRepository.findOneBy({ id });
  }

  async create(createBlogPostDto: CreateBlogPostDto): Promise<number> {
    const newBlogPost = this.blogPostsRepository.create({
      title: createBlogPostDto.title,
      body: createBlogPostDto.body
    });
    const blogPost = await this.blogPostsRepository.save(newBlogPost);
    return blogPost.id;
  }

  async remove(id: number): Promise<void> {
    await this.blogPostsRepository.delete(id);
  }
}
